%%
%% This is file `eqemail.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% eq2db.dtx  (with options: `copyright,eqemail')
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Eq2DB.sty package,             2001-9-01             %%
%% Copyright (C) 2014  D. P. Story                      %%
%%   dpstory@uakron.edu                                 %%
%%                                                      %%
%% This program can redistributed and/or modified under %%
%% the terms of the LaTeX Project Public License        %%
%% Distributed from CTAN archives in directory          %%
%% macros/latex/base/lppl.txt; either version 1 of the  %%
%% License, or (at your option) any later version.      %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\htmlSubmitType{HTML}
\def\insertHTMLs{,"pdfFileName","rtnURL"}
\def\eq@insertHiddenFields{%
    \ifx\basicFieldsSet\eqdb@NO
        \addHiddenTextField{mailTo}{}%
        \addHiddenTextField{courseName}{}%
        \addHiddenTextField{quizName}{}%
        \ifx\eqdb@submitType\htmlSubmitType
        \addHiddenTextField{pdfFileName}{}
        \addHiddenTextField{rtnURL}{\thisRtnURL}\fi
        \global\let\basicFieldsSet\eqdb@YES
    \fi
    \addHiddenTextField{\curr@quiz.ptScore}{}
    \addHiddenTextField{\curr@quiz.nPointTotal}{\theeqpointvalue}
    \addHiddenTextField{\curr@quiz.numQuestions}{\thequestionno}%
    \addHiddenTextField{\curr@quiz.numCorrect}{}%
    \addHiddenTextField{\curr@quiz.Responses}{}%
    \eq@addHiddenTextFields
    \eq@clearHiddenFields
}
\def\eq@submitURL{%
    this.getField("mailTo").value="\db@Name";\jsR\jsT\jsT
    this.getField("courseName").value="\db@Table";\jsR\jsT\jsT
    this.getField("quizName").value="\curr@quiz";\jsR\jsT\jsT
    this.getField("\curr@quiz.numCorrect").value=Score;\jsR\jsT\jsT
    this.getField("\curr@quiz.ptScore").value=ptScore;\jsR\jsT\jsT
\ifx\eqdb@submitType\htmlSubmitType
    this.getField("pdfFileName").value=%
        this.documentFileName;\jsR\jsT\jsT
\fi
    var aPointType=new Array(\aPointType);\jsR\jsT\jsT
\ifx\eqdb@tagged\eqdb@YES
    var cResponses=gatherTaggedQuizData("\currQuiz",%
        this.documentFileName,\thequestionno);\jsR\jsT\jsT
\else
    var cResponses=Responses.toString().substr(1);\jsR\jsT\jsT
\fi
    this.getField("\curr@quiz.Responses").value=cResponses;\jsR\jsT\jsT
    \eq@populateHiddenFields
    var aSubmitFields=new Array("\curr@quiz","IdInfo",%
        "mailTo","courseName","quizName"%
\ifx\eqdb@submitType\htmlSubmitType\insertHTMLs\fi);\jsR\jsT\jsT
    \priorSubmitQuiz
    this.submitForm({cURL: \eq@CGI,bEmpty: false,%
        aFields: aSubmitFields,%
        cSubmitAs: "\eqdb@submitType" });\jsR\jsT\jsT
}
\endinput
%%
%% End of file `eqemail.def'.
